@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js 23436 2010-06-22 12:29:28Z lstein $
+ $Id: controller.js 23705 2010-08-26 21:59:09Z lstein $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -32,7 +32,6 @@ var galaxy_form_id          = 'galaxy_form';
 var visible_span_id         = 'span';
 var search_form_objects_id  = 'search_form_objects';
 var userdata_table_id       = 'userdata_table_div';
-var userimport_table_id     = 'userimport_table_div';
 
 //  Sorta Constants
 var expired_limit  = 1;
@@ -233,24 +232,37 @@ var GBrowseController = Class.create({
   },
 
   append_child_from_html:
-  function (child_html,parent_obj) {
+  function (child_html,parent_obj,onTop) {
     //Append new html to the appropriate section This is a bit cludgy but we
     //create a temp element, read the html into it and then move the div
     //element back out.  This keeps the other tracks intact.
+    if (onTop == null) onTop = false;
+
     var tmp_element       = document.createElement("tmp_element");
     tmp_element.innerHTML = child_html;
-    parent_obj.appendChild(tmp_element);
 
+    var tracks      = parent_obj.getElementsByClassName('track');
+    var first_track = tracks[0];
+
+    if (onTop && first_track != null) {
+	parent_obj.insertBefore(tmp_element,first_track[0]);
+    } else {
+	parent_obj.appendChild(tmp_element);
+    }
     // Move each child node but skip if it is a comment (class is undef)
     if (tmp_element.hasChildNodes()) {
-      var children = tmp_element.childNodes;
-      for (var i = 0; i < children.length; i++) {
-        if (children[i].className == undefined){
-          continue;
-        }
-        parent_obj.appendChild(children[i]);
-      };
-    };
+	var children = tmp_element.childNodes;
+	for (var i = 0; i < children.length; i++) {
+	    if (children[i].className == undefined){
+		continue;
+	    }
+	    if (onTop && first_track != null) {
+		parent_obj.insertBefore(children[i],first_track);
+	    } else {
+		parent_obj.appendChild(children[i]);
+	    }
+	}
+    }
     parent_obj.removeChild(tmp_element);
   },
 
@@ -411,13 +423,13 @@ var GBrowseController = Class.create({
   }, // end scroll
 
   add_track:
-  function(track_name, onSuccessFunc, force) {
+  function(track_name, onSuccessFunc, force, onTop) {
     var track_names = new Array(track_name);
-    this.add_tracks(track_names,onSuccessFunc,force);
+    this.add_tracks(track_names,onSuccessFunc,force, onTop);
   },
 
   add_tracks:
-  function(track_names, onSuccessFunc, force) {
+  function(track_names, onSuccessFunc, force, onTop) {
 
     if (force == null) force=false;
 
@@ -464,7 +476,7 @@ var GBrowseController = Class.create({
           var html           = this_track_data.track_html;
           var panel_id       = this_track_data.panel_id;
 
-          Controller.append_child_from_html(html,$(panel_id));
+          Controller.append_child_from_html(html,$(panel_id),onTop);
 
           if (this_track_data.display_details == 0){
             $(ret_gbtrack.track_image_id).setOpacity(0);
@@ -892,7 +904,7 @@ var GBrowseController = Class.create({
 			  description: desc
 		      },
 		      onSuccess: function(transport) {
-		      Controller.update_sections(new Array(userdata_table_id,userimport_table_id))
+		      Controller.update_sections(new Array(userdata_table_id));
 		      }
 	       });
 	  el.stopObserving('keypress');
@@ -902,7 +914,7 @@ var GBrowseController = Class.create({
       }
       if (event.keyCode==Event.KEY_ESC) {
           el.innerHTML  = '<img src="' + Controller.button_url('spinner.gif') + '" alt="Working..." />';
-	  Controller.update_sections(new Array(userdata_table_id,userimport_table_id));
+	  Controller.update_sections(new Array(userdata_table_id));
 	  el.stopObserving('keypress');
 	  el.stopObserving('blur');
 	  el.blur();
@@ -927,38 +939,56 @@ var GBrowseController = Class.create({
 
   },
 
-  // uploadUserTrackSource() is called to submit a user track edit field
-  // to the server
-  uploadUserTrackSource:
-  function (sourceField,fileName,sourceFile,editElement) {
-
+  _modifyUserTrackSource:
+  function (param,statusElement,displayWhenDone) {
      var upload_id  = 'upload_' + Math.floor(Math.random() * 99999);
-
+     param.upload_id = upload_id;
      new Ajax.Request(Controller.url, {
      	 method:       'post',
-	 parameters:   { action:     'modifyUserData',
-                         track:      fileName,
-                         sourceFile: sourceFile,
-			 upload_id:  upload_id,
-			 data:       $F(sourceField)},
+	 parameters:   param,
          onCreate:    function() {
-	      if ($(editElement) != null) {
-	      	 $(editElement).innerHTML = '<div id="'+upload_id+'_form'+'"></div>'
+	      if ($(statusElement) != null) {
+	      	 $(statusElement).innerHTML = '<div id="'+upload_id+'_form'+'"></div>'
                                		   +'<div id="'+upload_id+'_status'+'"></div>';
 	      }
 	      startAjaxUpload(upload_id);
 	     },
          onSuccess:   function (transport) {
-	 	          if ($(editElement) != null) $(editElement).remove();
+	 	          if ($(statusElement) != null) $(statusElement).remove();
 			  var r = transport.responseJSON;
+			  Controller.add_tracks(r.tracks,null,false,true);
 			  r.tracks.each(function(t) {
 			  	      Controller.rerender_track(t,true,true);
 				      });
 		          var updater = Ajax_Status_Updater.get(upload_id);
 			  if (updater != null) updater.stop();
-		          Controller.update_sections(new Array(userdata_table_id,userimport_table_id,track_listing_id));
+		          Controller.update_sections(new Array(userdata_table_id,track_listing_id));
+			  if (displayWhenDone != null && displayWhenDone)
+			      Controller.select_tab('main_page');
 	               }
          });
+     
+  },
+
+  // uploadUserTrackSource() is called to submit a user track edit field
+  // to the server
+  uploadUserTrackSource:
+  function (sourceField,fileName,sourceFile,editElement) {
+      this._modifyUserTrackSource({ action:     'modifyUserData',
+				    track:      fileName,
+				    sourceFile: sourceFile,
+				    data:       $F(sourceField)
+                                   },
+	                          editElement);
+  },
+
+  // mirrorTrackSource() is called to mirror a URL to a track
+  mirrorTrackSource:
+  function (sourceURL,trackName,statusElement,displayWhenDone) {
+      this._modifyUserTrackSource( { action:     'upload_file',
+                                     name:       trackName,
+				     mirror_url: sourceURL },
+	                            statusElement,displayWhenDone);
   },
 
 // monitor_upload is redundant and needs to be refactored
@@ -981,6 +1011,18 @@ var GBrowseController = Class.create({
      if (this.tabs != null) {
        this.tabs.select_tab(tab_id);
      }
+  },
+
+  wait_for_initialization:
+  function (html,callback) {
+      $('main').setOpacity(0.2);
+      var html = '<div id="dialog_123" style="position:absolute; left:50px; top:50px; border:5px double black; background: wheat; z-index:100">'
+                 + html
+                 +'</div>';
+      $('main').insert({before:html});
+      if (callback) callback();
+      $('main').setOpacity(1.0);
+      $('dialog_123').remove();
   }
 
 
